.. currentmodule:: sardana.pool.pooltwodexpchannel

:mod:`~sardana.pool.pooltwodexpchannel`
=========================================

.. automodule:: sardana.pool.pooltwodexpchannel

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`Pool2DExpChannel`


Pool2DExpChannel
-------------------

.. inheritance-diagram:: Pool2DExpChannel
    :parts: 1
    
.. autoclass:: Pool2DExpChannel
    :show-inheritance:
    :members:
    :undoc-members:
